@@ -1,10 +1,9 @@
 import re
 import sys
 
-import six
-
-from great_expectations import exceptions as ge_exceptions
+from great_expectations import exceptions as ge_exceptions, DataContext
 from great_expectations.cli.cli_logging import logger
+from great_expectations.core import ExpectationSuite
 
 try:
     from termcolor import colored
@@ -31,7 +30,7 @@ def cli_message(string):
         "<red>(.*?)</red>", colored("\g<1>", "red"), mod_string, flags=flags
     )
 
-    six.print_(colored(mod_string))
+    print(colored(mod_string))
 
 
 def cli_message_list(string_list, list_intro_string=None):
@@ -100,10 +99,11 @@ def is_sane_slack_webhook(url):
     if url is None:
         return False
 
-    return "https://hooks.slack.com/" in url.strip()
+    return url.strip().startswith("https://hooks.slack.com/")
 
 
-def load_expectation_suite(context, suite_name):
+# TODO consolidate all the myriad CLI tests into this
+def load_expectation_suite(context: DataContext, suite_name: str) -> ExpectationSuite:
     """
     Load an expectation suite from a given context.
 
@@ -120,4 +120,22 @@ def load_expectation_suite(context, suite_name):
             "the name by running `great_expectations suite list` and try again."
         )
         logger.info(e)
+        # TODO this should try to send a usage statistic failure
+        sys.exit(1)
+
+
+# TODO consolidate all the myriad CLI tests into this
+def load_data_context_with_error_handling(directory: str) -> DataContext:
+    """Return a DataContext with good error handling and exit codes."""
+    try:
+        context = DataContext(directory)
+        return context
+    except (ge_exceptions.ConfigNotFoundError, ge_exceptions.InvalidConfigError) as err:
+        cli_message("<red>{}</red>".format(err.message))
+        sys.exit(1)
+    except ge_exceptions.PluginModuleNotFoundError as err:
+        cli_message(err.cli_colored_message)
+        sys.exit(1)
+    except ge_exceptions.PluginClassNotFoundError as err:
+        cli_message(err.cli_colored_message)
         sys.exit(1)
