@@ -1,15 +1,13 @@
-from __future__ import division
-
 import copy
 import inspect
 import logging
 from datetime import datetime
 from functools import wraps
+from typing import List
 
 import numpy as np
 import pandas as pd
 from dateutil.parser import parse
-from six import PY3, string_types
 
 from great_expectations.data_asset import DataAsset
 from great_expectations.data_asset.util import DocInherit, parse_result_format
@@ -61,10 +59,7 @@ class MetaSparkDFDataset(Dataset):
         See :func:`column_map_expectation <great_expectations.Dataset.base.Dataset.column_map_expectation>` \
         for full documentation of this function.
         """
-        if PY3:
-            argspec = inspect.getfullargspec(func)[0][1:]
-        else:
-            argspec = inspect.getargspec(func)[0][1:]
+        argspec = inspect.getfullargspec(func)[0][1:]
 
         @cls.expectation(argspec)
         @wraps(func)
@@ -131,7 +126,7 @@ class MetaSparkDFDataset(Dataset):
                         if val is None:
                             parsed_maybe_limited_unexpected_list.append(val)
                         else:
-                            if isinstance(val, string_types):
+                            if isinstance(val, str):
                                 val = parse(val)
                             parsed_maybe_limited_unexpected_list.append(datetime.strftime(val, output_strftime_format))
                     maybe_limited_unexpected_list = parsed_maybe_limited_unexpected_list
@@ -185,10 +180,7 @@ class MetaSparkDFDataset(Dataset):
         The column_pair_map_expectation decorator handles boilerplate issues surrounding the common pattern of evaluating
         truthiness of some condition on a per row basis across a pair of columns.
         """
-        if PY3:
-            argspec = inspect.getfullargspec(func)[0][1:]
-        else:
-            argspec = inspect.getargspec(func)[0][1:]
+        argspec = inspect.getfullargspec(func)[0][1:]
 
         @cls.expectation(argspec)
         @wraps(func)
@@ -269,7 +261,7 @@ class MetaSparkDFDataset(Dataset):
                         if val is None or (val[0] is None or val[1] is None):
                             parsed_maybe_limited_unexpected_list.append(val)
                         else:
-                            if isinstance(val[0], string_types) and isinstance(val[1], string_types):
+                            if isinstance(val[0], str) and isinstance(val[1], str):
                                 val = (parse(val[0]), parse(val[1]))
                             parsed_maybe_limited_unexpected_list.append((datetime.strftime(val[0], output_strftime_format), datetime.strftime(val[1], output_strftime_format)))
                     maybe_limited_unexpected_list = parsed_maybe_limited_unexpected_list
@@ -355,7 +347,7 @@ class SparkDFDataset(MetaSparkDFDataset):
     def get_column_count(self):
         return len(self.spark_df.columns)
 
-    def get_table_columns(self):
+    def get_table_columns(self) -> List[str]:
         return self.spark_df.columns
 
     def get_column_nonnull_count(self, column):
@@ -494,7 +486,7 @@ class SparkDFDataset(MetaSparkDFDataset):
         # find the number of values exactly equal to the upper bound to add those
 
         # We'll try for an optimization by asking for it at the same time
-        if added_max == True:
+        if added_max:
             upper_bound_count = temp_column.select(column).filter(col(column) == bins[-2]).count()
         else:
             upper_bound_count = 0
@@ -567,7 +559,7 @@ class SparkDFDataset(MetaSparkDFDataset):
             return column.withColumn('__success', lit(True))
         if parse_strings_as_datetimes:
             column = self._apply_dateutil_parse(column)
-            value_set = [parse(value) if isinstance(value, string_types) else value for value in value_set]
+            value_set = [parse(value) if isinstance(value, str) else value for value in value_set]
         if None in value_set:
             # spark isin returns None when any value is compared to None
             logger.error("expect_column_values_to_be_in_set cannot support a None in the value_set in spark")
@@ -709,10 +701,9 @@ class SparkDFDataset(MetaSparkDFDataset):
             try:
                 datetime.strptime(val, strftime_format)
                 return True
-            except TypeError as e:
+            except TypeError:
                 raise TypeError("Values passed to expect_column_values_to_match_strftime_format must be of type string.\nIf you want to validate a column of dates or timestamps, please call the expectation before converting from string format.")
-
-            except ValueError as e:
+            except ValueError:
                 return False
 
         success_udf = udf(is_parseable_by_format)
