@@ -1,5 +1,4 @@
-from __future__ import division
-from six import PY3, string_types
+from typing import List
 
 import uuid
 from functools import wraps
@@ -104,10 +103,7 @@ class MetaSqlAlchemyDataset(Dataset):
         The decorator will then use that filter to obtain unexpected elements, relevant counts, and return the formatted
         object.
         """
-        if PY3:
-            argspec = inspect.getfullargspec(func)[0][1:]
-        else:
-            argspec = inspect.getargspec(func)[0][1:]
+        argspec = inspect.getfullargspec(func)[0][1:]
 
         @cls.expectation(argspec)
         @wraps(func)
@@ -195,7 +191,7 @@ class MetaSqlAlchemyDataset(Dataset):
                 output_strftime_format = kwargs["output_strftime_format"]
                 maybe_limited_unexpected_list = []
                 for x in unexpected_query_results.fetchall():
-                    if isinstance(x[column], string_types):
+                    if isinstance(x[column], str):
                         col = parse(x[column])
                     else:
                         col = x[column]
@@ -253,6 +249,9 @@ class SqlAlchemyDataset(MetaSqlAlchemyDataset):
             #was used for a temp table and raising an error
             schema = None
             table_name = "ge_tmp_" + str(uuid.uuid4())[:8]
+            # mssql expects all temporary table names to have a prefix '#'
+            if engine.dialect.name.lower() == "mssql":
+                table_name = "#" + table_name
             generated_table_name = table_name
         else:
             generated_table_name = None
@@ -279,8 +278,8 @@ class SqlAlchemyDataset(MetaSqlAlchemyDataset):
             # These are the officially included and supported dialects by sqlalchemy
             self.dialect = import_module("sqlalchemy.dialects." + self.engine.dialect.name)
 
-            if engine and engine.dialect.name.lower() == "sqlite":
-                # sqlite temp tables only persist within a connection so override the engine
+            if engine and engine.dialect.name.lower() in ["sqlite", "mssql"]:
+                # sqlite/mssql temp tables only persist within a connection so override the engine
                 self.engine = engine.connect()
         elif self.engine.dialect.name.lower() == "snowflake":
             self.dialect = import_module("snowflake.sqlalchemy.snowdialect")
@@ -325,6 +324,10 @@ class SqlAlchemyDataset(MetaSqlAlchemyDataset):
             # reflection will not find the temporary schema
             self.columns = self.column_reflection_fallback()
 
+        # Use fallback because for mssql reflection doesn't throw an error but returns an empty list
+        if len(self.columns) == 0:
+            self.columns = self.column_reflection_fallback()
+
         # Only call super once connection is established and table_name and columns known to allow autoinspection
         super(SqlAlchemyDataset, self).__init__(*args, **kwargs)
 
@@ -351,6 +354,10 @@ class SqlAlchemyDataset(MetaSqlAlchemyDataset):
                 head_sql_str += self._table.name
             head_sql_str += " limit {0:d}".format(n)
 
+            # Limit is unknown in mssql! Use top instead!
+            if self.engine.dialect.name.lower() == "mssql":
+                head_sql_str = "select top({n}) * from {table}".format(n=n, table=self._table.name)
+
             df = pd.read_sql(head_sql_str, con=self.engine)
 
         return PandasDataset(
@@ -371,7 +378,7 @@ class SqlAlchemyDataset(MetaSqlAlchemyDataset):
     def get_column_count(self):
         return len(self.columns)
 
-    def get_table_columns(self):
+    def get_table_columns(self) -> List[str]:
         return [col['name'] for col in self.columns]
 
     def get_column_nonnull_count(self, column):
@@ -482,8 +489,13 @@ class SqlAlchemyDataset(MetaSqlAlchemyDataset):
         return column_median
 
     def get_column_quantiles(self, column, quantiles, allow_relative_error=False):
-        selects = [sa.func.percentile_disc(quantile).within_group(
-            sa.column(column).asc()) for quantile in quantiles]
+        if self.engine.dialect.name.lower() != "mssql":
+            selects = [sa.func.percentile_disc(quantile).within_group(
+                sa.column(column).asc()) for quantile in quantiles]
+        else:
+            # mssql requires over(), so we add an empty over() clause
+            selects = [sa.func.percentile_disc(quantile).within_group(
+                sa.column(column).asc()).over() for quantile in quantiles]
         try:
             if isinstance(self.engine.dialect, sqlalchemy_redshift.dialect.RedshiftDialect):
                 # Redshift does not have a percentile_disc method, but does support an approximate version
@@ -501,9 +513,15 @@ class SqlAlchemyDataset(MetaSqlAlchemyDataset):
         return list(quantiles)
 
     def get_column_stdev(self, column):
-        res = self.engine.execute(sa.select([
-                sa.func.stddev_samp(sa.column(column))
-            ]).select_from(self._table).where(sa.column(column) != None)).fetchone()
+        if self.engine.dialect.name.lower() != "mssql":
+            res = self.engine.execute(sa.select([
+                    sa.func.stddev_samp(sa.column(column))
+                ]).select_from(self._table).where(sa.column(column) != None)).fetchone()
+        else:
+            # stdev_samp is not a recognized built-in function name but stdevp does exist for mssql!
+            res = self.engine.execute(sa.select([
+                    sa.func.stdevp(sa.column(column))
+                ]).select_from(self._table).where(sa.column(column) != None)).fetchone()
         return float(res[0])
 
     def get_column_hist(self, column, bins):
@@ -664,6 +682,16 @@ class SqlAlchemyDataset(MetaSqlAlchemyDataset):
         elif self.engine.dialect.name == "mysql":
             stmt = "CREATE TEMPORARY TABLE {table_name} AS {custom_sql}".format(
                 table_name=table_name, custom_sql=custom_sql)
+        elif self.engine.dialect.name == "mssql":
+            # Insert "into #{table_name}" in the custom sql query right before the "from" clause
+            # Split is case sensitive so detect case.
+            # Note: transforming custom_sql to uppercase/lowercase has uninteded consequences (i.e., changing column names), so this is not an option!
+            if 'from' in custom_sql:
+                strsep = 'from'
+            else:
+                strsep = 'FROM'
+            custom_sqlmod = custom_sql.split(strsep, maxsplit=1)
+            stmt = (custom_sqlmod[0] + "into {table_name} from" + custom_sqlmod[1]).format(table_name=table_name)
         else:
             stmt = "CREATE TEMPORARY TABLE \"{table_name}\" AS {custom_sql}".format(
                 table_name=table_name, custom_sql=custom_sql)
@@ -671,9 +699,16 @@ class SqlAlchemyDataset(MetaSqlAlchemyDataset):
 
     def column_reflection_fallback(self):
         """If we can't reflect the table, use a query to at least get column names."""
-        sql = sa.select([sa.text("*")]).select_from(self._table).limit(1)
-        col_names = self.engine.execute(sql).keys()
-        col_dict = [{'name': col_name} for col_name in col_names]
+        if self.engine.dialect.name.lower() != "mssql":
+            sql = sa.select([sa.text("*")]).select_from(self._table).limit(1)
+            col_names = self.engine.execute(sql).keys()
+            col_dict = [{'name': col_name} for col_name in col_names]
+        else:
+            type_module = self._get_dialect_type_module()
+            # Get column names and types from the database
+            # StackOverflow to the rescue: https://stackoverflow.com/a/38634368
+            col_info = self.engine.execute("SELECT cols.NAME,ty.NAME FROM tempdb.sys.columns cols JOIN sys.types ty ON cols.user_type_id = ty.user_type_id WHERE object_id = OBJECT_ID('tempdb..{}')".format(self._table)).fetchall()
+            col_dict = [{'name': col_name, 'type': getattr(type_module,col_type.upper())()} for col_name,col_type in col_info]
         return col_dict
 
     ###
@@ -1034,7 +1069,7 @@ class SqlAlchemyDataset(MetaSqlAlchemyDataset):
             mostly=None,
             result_format=None, include_config=True, catch_exceptions=None, meta=None
     ):
-        regex_expression = self._get_dialect_regex_expression(column, regex, positive=True)
+        regex_expression = self._get_dialect_regex_expression(column, regex)
         if regex_expression is None:
             logger.warning("Regex is not supported for dialect %s" % str(self.engine.dialect))
             raise NotImplementedError
@@ -1071,7 +1106,7 @@ class SqlAlchemyDataset(MetaSqlAlchemyDataset):
         if len(regex_list) == 0:
             raise ValueError("At least one regex must be supplied in the regex_list.")
 
-        regex_expression = self._get_dialect_regex_expression(column, regex_list[0], positive=True)
+        regex_expression = self._get_dialect_regex_expression(column, regex_list[0])
         if regex_expression is None:
             logger.warning("Regex is not supported for dialect %s" % str(self.engine.dialect))
             raise NotImplementedError
@@ -1079,12 +1114,12 @@ class SqlAlchemyDataset(MetaSqlAlchemyDataset):
         if match_on == "any":
             condition = \
                 sa.or_(
-                    *[self._get_dialect_regex_expression(column, regex, positive=True) for regex in regex_list]
+                    *[self._get_dialect_regex_expression(column, regex) for regex in regex_list]
                 )
         else:
             condition = \
                 sa.and_(
-                    *[self._get_dialect_regex_expression(column, regex, positive=True) for regex in regex_list]
+                    *[self._get_dialect_regex_expression(column, regex) for regex in regex_list]
                 )
         return condition
 
