@@ -1,8 +1,6 @@
 # -*- coding: utf-8 -*-
 
 import copy
-from six import string_types
-
 import logging
 
 from ruamel.yaml import YAML
@@ -38,12 +36,12 @@ class Datasource(object):
     in how to obtain data such as with time-based partitioning, downsampling, or other techniques
     appropriate for the datasource.
 
-    For example, a generator could produce a SQL query that logically represents "rows in the Events
+    For example, a batch kwargs generator could produce a SQL query that logically represents "rows in the Events
     table with a timestamp on February 7, 2012," which a SqlAlchemyDatasource could use to materialize
     a SqlAlchemyDataset corresponding to that batch of data and ready for validation.
 
     Since opinionated DAG managers such as airflow, dbt, prefect.io, dagster can also act as datasources
-    and/or generators for a more generic datasource.
+    and/or batch kwargs generators for a more generic datasource.
 
     When adding custom expectations by subclassing an existing DataAsset type, use the data_asset_type parameter
     to configure the datasource to load and return DataAssets of the custom type.
@@ -70,29 +68,29 @@ class Datasource(object):
             class_name,
             module_name="great_expectations.datasource",
             data_asset_type=None,
-            generators=None,
+            batch_kwargs_generators=None,
             **kwargs
     ):
         """
-        Build a full configuration object for a datasource, potentially including generators with defaults.
+        Build a full configuration object for a datasource, potentially including batch kwargs generators with defaults.
 
         Args:
             class_name: The name of the class for which to build the config
             module_name: The name of the module in which the datasource class is located
             data_asset_type: A ClassConfig dictionary
-            generators: Generator configuration dictionary
+            batch_kwargs_generators: BatchKwargGenerators configuration dictionary
             **kwargs: Additional kwargs to be part of the datasource constructor's initialization
 
         Returns:
             A complete datasource configuration.
 
         """
-        verify_dynamic_loading_support(module_name=module_name, package_name=None)
+        verify_dynamic_loading_support(module_name=module_name)
         class_ = load_class(class_name=class_name, module_name=module_name)
-        configuration = class_.build_configuration(data_asset_type=data_asset_type, generators=generators, **kwargs)
+        configuration = class_.build_configuration(data_asset_type=data_asset_type, batch_kwargs_generators=batch_kwargs_generators, **kwargs)
         return configuration
 
-    def __init__(self, name, data_context=None, data_asset_type=None, generators=None, **kwargs):
+    def __init__(self, name, data_context=None, data_asset_type=None, batch_kwargs_generators=None, **kwargs):
         """
         Build a new datasource.
 
@@ -100,21 +98,21 @@ class Datasource(object):
             name: the name for the datasource
             data_context: data context to which to connect
             data_asset_type (ClassConfig): the type of DataAsset to produce
-            generators: generators to add to the datasource
+            batch_kwargs_generators: BatchKwargGenerators to add to the datasource
         """
         self._data_context = data_context
         self._name = name
-        if isinstance(data_asset_type, string_types):
+        if isinstance(data_asset_type, str):
             warnings.warn(
                 "String-only configuration for data_asset_type is deprecated. Use module_name and class_name instead.",
                 DeprecationWarning)
         self._data_asset_type = data_asset_type
         self._datasource_config = kwargs
-        self._generators = {}
+        self._batch_kwargs_generators = {}
 
         self._datasource_config["data_asset_type"] = data_asset_type
-        if generators is not None:
-            self._datasource_config["generators"] = generators
+        if batch_kwargs_generators is not None:
+            self._datasource_config["batch_kwargs_generators"] = batch_kwargs_generators
 
     @property
     def name(self):
@@ -136,107 +134,92 @@ class Datasource(object):
 
     def _build_generators(self):
         """
-        Build generator objects from the datasource configuration.
+        Build batch kwargs generator objects from the datasource configuration.
 
         Returns:
             None
         """
         try:
-            for generator in self._datasource_config["generators"].keys():
-                self.get_generator(generator)
+            for generator in self._datasource_config["batch_kwargs_generators"].keys():
+                self.get_batch_kwargs_generator(generator)
         except KeyError:
             pass
 
-    def add_generator(self, name, class_name, **kwargs):
-        """Add a generator to the datasource.
+    def add_batch_kwargs_generator(self, name, class_name, **kwargs):
+        """Add a BatchKwargGenerator to the datasource.
 
         Args:
-            name (str): the name of the new generator to add
-            class_name: class of the generator to add
-            kwargs: additional keyword arguments will be passed directly to the new generator's constructor
+            name (str): the name of the new BatchKwargGenerator to add
+            class_name: class of the BatchKwargGenerator to add
+            kwargs: additional keyword arguments will be passed directly to the new BatchKwargGenerator's constructor
 
         Returns:
-             generator (Generator)
+             BatchKwargGenerator (BatchKwargGenerator)
         """
-
-        # PENDING DELETION - 20200130 - JPC
-        # 0.9.0 removes support for the type system
-        # if isinstance(generator_config, string_types):
-        #     warnings.warn("Configuring generators with a type name is no longer supported. Please update to new-style "
-        #                   "configuration.")
-        #     generator_config = {
-        #         "type": generator_config
-        #     }
-        # generator_config.update(kwargs)
         kwargs["class_name"] = class_name
-        generator = self._build_generator(**kwargs)
-        if "generators" not in self._datasource_config:
-            self._datasource_config["generators"] = dict()
-        self._datasource_config["generators"][name] = kwargs
+        generator = self._build_batch_kwargs_generator(**kwargs)
+        if "batch_kwargs_generators" not in self._datasource_config:
+            self._datasource_config["batch_kwargs_generators"] = dict()
+        self._datasource_config["batch_kwargs_generators"][name] = kwargs
 
         return generator
 
-    def _build_generator(self, **kwargs):
-        """Build a generator using the provided configuration and return the newly-built generator."""
-        module_name = 'great_expectations.datasource.generator'
+    def _build_batch_kwargs_generator(self, **kwargs):
+        """Build a BatchKwargGenerator using the provided configuration and return the newly-built generator."""
         generator = instantiate_class_from_config(
             config=kwargs,
             runtime_environment={
                 "datasource": self
             },
             config_defaults={
-                "module_name": module_name
+                "module_name": "great_expectations.datasource.batch_kwargs_generator"
             }
         )
         if not generator:
             raise ClassInstantiationError(
-                module_name=module_name,
+                module_name="great_expectations.datasource.batch_kwargs_generator",
                 package_name=None,
                 class_name=kwargs['class_name']
             )
 
         return generator
 
-    def get_generator(self, generator_name):
-        """Get the (named) generator from a datasource)
+    def get_batch_kwargs_generator(self, name):
+        """Get the (named) BatchKwargGenerator from a datasource)
 
         Args:
-            generator_name (str): name of generator (default value is 'default')
+            name (str): name of BatchKwargGenerator (default value is 'default')
 
         Returns:
-            generator (Generator)
+            BatchKwargGenerator (BatchKwargGenerator)
         """
-        if generator_name in self._generators:
-            return self._generators[generator_name]
-        elif "generators" in self._datasource_config and generator_name in self._datasource_config["generators"]:
-            generator_config = copy.deepcopy(self._datasource_config["generators"][generator_name])
+        if name in self._batch_kwargs_generators:
+            return self._batch_kwargs_generators[name]
+        elif "batch_kwargs_generators" in self._datasource_config and name in self._datasource_config["batch_kwargs_generators"]:
+            generator_config = copy.deepcopy(self._datasource_config["batch_kwargs_generators"][name])
         else:
             raise ValueError(
-                "Unable to load generator %s -- no configuration found or invalid configuration." % generator_name
+                "Unable to load batch kwargs generator %s -- no configuration found or invalid configuration." % name
             )
-        generator = self._build_generator(**generator_config)
-        self._generators[generator_name] = generator
+        generator = self._build_batch_kwargs_generator(**generator_config)
+        self._batch_kwargs_generators[name] = generator
         return generator
 
-    def list_generators(self):
-        """List currently-configured generators for this datasource.
+    def list_batch_kwargs_generators(self):
+        """List currently-configured BatchKwargGenerator for this datasource.
 
         Returns:
             List(dict): each dictionary includes "name" and "type" keys
         """
         generators = []
 
-        if "generators" in self._datasource_config:
-            for key, value in self._datasource_config["generators"].items():
+        if "batch_kwargs_generators" in self._datasource_config:
+            for key, value in self._datasource_config["batch_kwargs_generators"].items():
                 generators.append({
                     "name": key,
                     "class_name": value["class_name"]
                 })
-        else:
-            generators.append({
-                "name": None,
-                "class_name": None
-            })
+
         return generators
 
     def process_batch_parameters(self, limit=None, dataset_options=None):
@@ -279,13 +262,16 @@ class Datasource(object):
         """
         raise NotImplementedError
 
-    def get_available_data_asset_names(self, generator_names=None):
-        """Returns a dictionary of data_asset_names that the specified generator can provide. Note that some generators
-        may not be capable of describing specific named data assets, and some
-        generators (such as filesystem glob generators) require the user to configure data asset names.
+    def get_available_data_asset_names(self, batch_kwargs_generator_names=None):
+        """
+        Returns a dictionary of data_asset_names that the specified batch kwarg
+        generator can provide. Note that some batch kwargs generators may not be
+        capable of describing specific named data assets, and some (such as
+        filesystem glob batch kwargs generators) require the user to configure
+        data asset names.
 
         Args:
-            generator_names: the generators for which to get available data asset names.
+            batch_kwargs_generator_names: the BatchKwargGenerator for which to get available data asset names.
 
         Returns:
             dictionary consisting of sets of generator assets available for the specified generators:
@@ -300,18 +286,18 @@ class Datasource(object):
 
         """
         available_data_asset_names = {}
-        if generator_names is None:
-            generator_names = [generator["name"] for generator in self.list_generators()]
-        elif isinstance(generator_names, string_types):
-            generator_names = [generator_names]
+        if batch_kwargs_generator_names is None:
+            batch_kwargs_generator_names = [generator["name"] for generator in self.list_batch_kwargs_generators()]
+        elif isinstance(batch_kwargs_generator_names, str):
+            batch_kwargs_generator_names = [batch_kwargs_generator_names]
 
-        for generator_name in generator_names:
-            generator = self.get_generator(generator_name)
+        for generator_name in batch_kwargs_generator_names:
+            generator = self.get_batch_kwargs_generator(generator_name)
             available_data_asset_names[generator_name] = generator.get_available_data_asset_names()
         return available_data_asset_names
 
-    def build_batch_kwargs(self, generator, name=None, partition_id=None, **kwargs):
-        generator_obj = self.get_generator(generator)
+    def build_batch_kwargs(self, batch_kwargs_generator, name=None, partition_id=None, **kwargs):
+        generator_obj = self.get_batch_kwargs_generator(batch_kwargs_generator)
         if partition_id is not None:
             kwargs["partition_id"] = partition_id
         return generator_obj.build_batch_kwargs(name=name, **kwargs)
