@@ -136,29 +136,31 @@ class ExpectationStringRenderer(ContentBlockRenderer):
             ["column", "min_value", "max_value", "mostly"]
         )
 
+        template_str = ""
         if (params["min_value"] is None) and (params["max_value"] is None):
-            template_str = "may have any numerical value."
+            template_str += "may have any numerical value."
         else:
             if params["mostly"] is not None:
                 params["mostly_pct"] = num_to_str(params["mostly"] * 100, precision=15, no_scientific=True)
                 # params["mostly_pct"] = "{:.14f}".format(params["mostly"]*100).rstrip("0").rstrip(".")
                 if params["min_value"] is not None and params["max_value"] is not None:
-                    template_str = "values must be between $min_value and $max_value, at least $mostly_pct % of the time."
+                    template_str += "values must be between $min_value and $max_value, " \
+                                    "at least $mostly_pct % of the time."
 
                 elif params["min_value"] is None:
-                    template_str = "values must be less than $max_value, at least $mostly_pct % of the time."
+                    template_str += "values must be less than $max_value, at least $mostly_pct % of the time."
 
                 elif params["max_value"] is None:
-                    template_str = "values must be less than $max_value, at least $mostly_pct % of the time."
+                    template_str += "values must be less than $max_value, at least $mostly_pct % of the time."
             else:
                 if params["min_value"] is not None and params["max_value"] is not None:
-                    template_str = "values must always be between $min_value and $max_value."
+                    template_str += "values must always be between $min_value and $max_value."
 
                 elif params["min_value"] is None:
-                    template_str = "values must always be less than $max_value."
+                    template_str += "values must always be less than $max_value."
 
                 elif params["max_value"] is None:
-                    template_str = "values must always be more than $min_value."
+                    template_str += "values must always be more than $min_value."
 
         if include_column_name:
             template_str = "$column " + template_str
