@@ -1,8 +1,6 @@
 import logging
 import os
 
-from six import string_types
-
 from collections import OrderedDict
 
 from ...core.id_dict import BatchKwargs
@@ -25,8 +23,8 @@ logger = logging.getLogger(__name__)
 
 
 class ValidationResultsPageRenderer(Renderer):
-
     def __init__(self, column_section_renderer=None):
+        super().__init__()
         if column_section_renderer is None:
             column_section_renderer = {
                 "class_name": "ValidationResultsColumnSectionRenderer"
@@ -54,7 +52,7 @@ class ValidationResultsPageRenderer(Renderer):
 
         # add datasource key to batch_kwargs if missing
         if 'datasource' not in validation_results.meta.get("batch_kwargs", {}):
-            # check if expectation_suite_name follows datasource.generator.data_asset_name.suite_name pattern
+            # check if expectation_suite_name follows datasource.batch_kwargs_generator.data_asset_name.suite_name pattern
             if len(expectation_suite_name.split('.')) == 4:
                 batch_kwargs['datasource'] = expectation_suite_name.split('.')[0]
 
@@ -390,8 +388,8 @@ class ValidationResultsPageRenderer(Renderer):
 
 
 class ExpectationSuitePageRenderer(Renderer):
-
     def __init__(self, column_section_renderer=None):
+        super().__init__()
         if column_section_renderer is None:
             column_section_renderer = {
                 "class_name": "ExpectationSuiteColumnSectionRenderer"
@@ -529,7 +527,7 @@ class ExpectationSuitePageRenderer(Renderer):
                 columns.append(exp.kwargs["column"])
         total_columns = len(set(columns))
 
-        content = content + [
+        content += [
             # TODO: Leaving these two paragraphs as placeholders for later development.
             # "This Expectation suite was first generated by {BasicDatasetProfiler} on {date}, using version {xxx} of Great Expectations.",
             # "{name}, {name}, and {name} have also contributed additions and revisions.",
@@ -543,7 +541,7 @@ class ExpectationSuitePageRenderer(Renderer):
             notes = expectations.meta["notes"]
             note_content = None
 
-            if isinstance(notes, string_types):
+            if isinstance(notes, str):
                 note_content = [notes]
 
             elif isinstance(notes, list):
@@ -552,7 +550,7 @@ class ExpectationSuitePageRenderer(Renderer):
             elif isinstance(notes, dict):
                 if "format" in notes:
                     if notes["format"] == "string":
-                        if isinstance(notes["content"], string_types):
+                        if isinstance(notes["content"], str):
                             note_content = [notes["content"]]
                         elif isinstance(notes["content"], list):
                             note_content = notes["content"]
@@ -560,7 +558,7 @@ class ExpectationSuitePageRenderer(Renderer):
                             logger.warning("Unrecognized Expectation suite notes format. Skipping rendering.")
 
                     elif notes["format"] == "markdown":
-                        if isinstance(notes["content"], string_types):
+                        if isinstance(notes["content"], str):
                             note_content = [
                                 RenderedMarkdownContent(**{
                                     "content_block_type": "markdown",
@@ -588,7 +586,7 @@ class ExpectationSuitePageRenderer(Renderer):
                     logger.warning("Unrecognized Expectation suite notes format. Skipping rendering.")
 
             if note_content is not None:
-                content = content + note_content
+                content += note_content
 
         return TextContent(**{
             "content_block_type": "text",
@@ -613,8 +611,8 @@ class ExpectationSuitePageRenderer(Renderer):
 
 
 class ProfilingResultsPageRenderer(Renderer):
-
     def __init__(self, overview_section_renderer=None, column_section_renderer=None):
+        super().__init__()
         if overview_section_renderer is None:
             overview_section_renderer = {
                 "class_name": "ProfilingResultsOverviewSectionRenderer"
@@ -659,7 +657,7 @@ class ProfilingResultsPageRenderer(Renderer):
 
         # add datasource key to batch_kwargs if missing
         if 'datasource' not in validation_results.meta.get("batch_kwargs", {}):
-            # check if expectation_suite_name follows datasource.generator.data_asset_name.suite_name pattern
+            # check if expectation_suite_name follows datasource.batch_kwargs_generator.data_asset_name.suite_name pattern
             if len(expectation_suite_name.split('.')) == 4:
                 batch_kwargs['datasource'] = expectation_suite_name.split('.')[0]
 
